@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "customtoolspluginmanager.h"
@@ -32,12 +20,7 @@ using namespace PimCommon;
 class CustomToolsPluginInfo
 {
 public:
-    CustomToolsPluginInfo()
-        : plugin(nullptr)
-    {
-    }
-
-    QString saveName() const;
+    Q_REQUIRED_RESULT QString saveName() const;
 
     KPluginMetaData metaData;
     PimCommon::CustomToolsPlugin *plugin = nullptr;
@@ -48,7 +31,8 @@ QString CustomToolsPluginInfo::saveName() const
     return QFileInfo(metaData.fileName()).baseName();
 }
 
-namespace {
+namespace
+{
 QString pluginVersion()
 {
     return QStringLiteral("1.0");
@@ -67,7 +51,7 @@ public:
     void initializePluginList();
     void loadPlugin(CustomToolsPluginInfo *item);
     QVector<CustomToolsPluginInfo> mPluginList;
-    CustomToolsPluginManager *q;
+    CustomToolsPluginManager *const q;
 };
 
 void CustomToolsPluginManagerPrivate::initializePluginList()
