@@ -86,7 +86,6 @@ bool GenericPluginManagerPrivate::initializePlugins()
     const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
     QVectorIterator<KPluginMetaData> i(plugins);
     i.toBack();
-    QSet<QString> unique;
     while (i.hasPrevious()) {
         GenericPluginInfo info;
         const KPluginMetaData data = i.previous();
@@ -101,13 +100,8 @@ bool GenericPluginManagerPrivate::initializePlugins()
         info.metaDataFileName = data.fileName();
 
         if (pluginVersion() == data.version()) {
-            // only load plugins once, even if found multiple times!
-            if (unique.contains(info.metaDataFileNameBaseName)) {
-                continue;
-            }
             info.plugin = nullptr;
             mPluginList.push_back(info);
-            unique.insert(info.metaDataFileNameBaseName);
         } else {
             qCWarning(PIMCOMMON_LOG) << "Plugin " << data.name() << " doesn't have correction plugin version. It will not be loaded.";
         }
