@@ -1,11 +1,10 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef MIGRATEAPPLICATIONFILESTEST_H
-#define MIGRATEAPPLICATIONFILESTEST_H
+#pragma once
 
 #include <QObject>
 
@@ -31,4 +30,3 @@ private Q_SLOTS:
     void shouldNotMigrateIfAlreadyDone();
 };
 
-#endif // MIGRATEAPPLICATIONFILESTEST_H
